use crate::game::Game;

pub enum PlayerCheck {
	Ok(String),
	Err(Vec<String>),
}

impl Game {
	pub fn check_player_name<S: Into<String>>(&self, name: S) -> PlayerCheck {
		let name = name.into();
		let name = name.trim();
		let mut err_vec = Vec::<String>::new();

		if name.len() < self.config.player.name_min {
			err_vec.push(format!("{} character minimum", self.config.player.name_min));
		} else if name.len() > self.config.player.name_max {
			err_vec.push(format!("{} character maximum", self.config.player.name_max));
		}

		for c in name.chars() {
			if !self.config.player.name_chars.contains(&c.to_string()) {
				err_vec.push(format!("Allowed characters are: {}", self.config.player.name_chars));
				break;
			}
		}

		if !err_vec.is_empty() {
			PlayerCheck::Err(err_vec)
		} else {
			PlayerCheck::Ok(name.into())
		}
	}

	pub fn check_player_password<S: Into<String>>(&self, password: S) -> PlayerCheck {
		let password = password.into();
		let mut err_vec = Vec::<String>::new();

		if password.len() < self.config.player.pass_min {
			err_vec.push(format!("{} character minimum", self.config.player.pass_min));
		} else if password.len() > self.config.player.pass_max {
			err_vec.push(format!("{} character maximum", self.config.player.pass_max));
		}

		for c in password.chars() {
			if !self.config.player.pass_chars.contains(&c.to_string()) {
				err_vec.push(format!("Allowed characters are: {}", self.config.player.pass_chars));
				break;
			}
		}

		if err_vec.is_empty() {
			PlayerCheck::Ok(password.into())
		} else {
			PlayerCheck::Err(err_vec)
		}
	}
}
